==> rktSNS_1.070120.tgz: rktSNS/mobapp/modules/public/login/login.php <==
<?php
/* ========================================================================
 - [modules/public/login/login.php]
 -      ログイン
 -      Copyright (c) 2006 Yujiro Takahashi
 - ライセンス:
 -      This program is free software; you can redistribute it and/or
 -      modify it under the terms of the GNU General Public License
 -      as published by the Free Software Foundation; either version 2
 -      of the License, or (at your option) any later version.
 -
 -      This program is distributed in the hope that it will be useful,
 -      but WITHOUT ANY WARRANTY; without even the implied warranty of
 -      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 -      GNU General Public License for more details.
 -
 -      You should have received a copy of the GNU General Public License
 -      along with this program; if not, write to the Free Software
 -      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 - 問い合わせ先：
 -      yujiro@rakuto.net
 -      http://rakuto.net/rktSNS/
 - 更新履歴：
 -      [2006/07/10] 作成
 - ======================================================================== */

/* =-=- モジュール等の読み込み -=-= */
require_once WEBAPP_LIB_DIR.'wap_public.php';

/**
 * WebApplication実装クラス
 *
 * @author 高橋 裕志郎 <yujiro@rakuto.net>
 * @package webapp
 * @access public
 * @version 1.0
 */
class webapp extends WAP_public
{
    /**
     * 自動ログインフラグ
     * @var integer
     */
    var $autologin = null;
    
    /**
     * 実行処理
     *
     * @access public
     * @return void
     **/
    function execute()
    {
        /* URL引数の取得 */
        $this->setSafety('autologin','_POST');

        $url = HTTP_ACTION.'public/content/default/'.$this->sid.'/';
        $url = empty($_REQUEST['url'])?$url:$_REQUEST['url'];
        $session_id = empty($_REQUEST['sid'])?null:$_REQUEST['sid'];

        $objauth = new RKT_auth($session_id);
        if (!$objauth->logIn()){
            $url = HTTP_ACTION.'public/login/reissue'.$this->sid.'/'.WAP_URI_SEPARATOR.'mismatch=1';
        }

        header('Location: '.$url);
        if (!empty($this->autologin)){
            $objauth->setAutoLogin();
        }
        exit();
    }
} // webapp
?>

==> rktSNS_1.070430.tgz: rktSNS/mobapp/modules/public/login/login.php <==
<?php
/* ========================================================================
 - [modules/public/login/login.php]
 -      ログイン
 -      Copyright (c) 2006 Yujiro Takahashi
 - ライセンス:
 -      This program is free software; you can redistribute it and/or
 -      modify it under the terms of the GNU General Public License
 -      as published by the Free Software Foundation; either version 2
 -      of the License, or (at your option) any later version.
 -
 -      This program is distributed in the hope that it will be useful,
 -      but WITHOUT ANY WARRANTY; without even the implied warranty of
 -      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 -      GNU General Public License for more details.
 -
 -      You should have received a copy of the GNU General Public License
 -      along with this program; if not, write to the Free Software
 -      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 - 問い合わせ先：
 -      yujiro@rakuto.net
 -      http://rakuto.net/rktSNS/
 - 更新履歴：
 -      [2006/07/10] 作成
 - ======================================================================== */

/* =-=- モジュール等の読み込み -=-= */
require_once WEBAPP_LIB_DIR.'wap_public.php';

/**
 * WebApplication実装クラス
 *
 * @author 高橋 裕志郎 <yujiro@rakuto.net>
 * @package webapp
 * @access public
 * @version 1.0
 */
class webapp extends WAP_public
{
    /**
     * 自動ログインフラグ
     * @var integer
     */
    var $autologin = null;
    
    /**
     * 実行処理
     *
     * @access public
     * @return void
     **/
    function execute()
    {
        /* URL引数の取得 */
        $this->setSafety('autologin','_POST');

        $url = HTTP_ACTION.'private/home/menu/'.$this->sid.'/';
        $url = empty($_REQUEST['url'])?$url:$_REQUEST['url'];
        $session_id = empty($_REQUEST['sid'])?null:$_REQUEST['sid'];

        $objauth = new RKT_auth($session_id);
        if (!$objauth->logIn()){
            $url = HTTP_ACTION.'public/login/reissue'.$this->sid.'/'.WAP_URI_SEPARATOR.'mismatch=1';
        }

        header('Location: '.$url);
        if (!empty($this->autologin)){
            $objauth->setAutoLogin();
        }
        exit();
    }
} // webapp
?>
